@@ -236,7 +236,7 @@ class Crp:
         target_value = self.getTargetValues(train_data,target_frame)
         print('target value done')
         # Calculate features
-        df = self.getFeaturesMatrix(train_data,orders,lag,items_dataset)
+        df = self.getFeaturesMatrix(train_data,original_dataset,lag,items_dataset)
         
         # Merge feature sets
         data = self.getMergedDF(df,'customerid')
